@@ -93,7 +93,7 @@ fn write_function_overloaded_invoke_with_error_handling(w: &mut IndentWriter, fu
             indented!(w, [_], r#"var rval = {};"#, fn_call)?;
             indented!(w, [_], r#"if (rval != {}.{})"#, e.the_enum().rust_name(), e.success_variant().name())?;
             indented!(w, [_], r#"{{"#)?;
-            indented!(w, [_ _], r#"throw new Exception($"Something went wrong: {{rval}}");"#)?;
+            indented!(w, [_ _], r#"throw new InteropException(rval);"#)?;
             indented!(w, [_], r#"}}"#)?;
         }
         CType::Primitive(PrimitiveType::Void) => {
